@@ -1,9 +1,9 @@
 #' Print a short summary for a causal model
 #'
-#' print method for class "\code{causal_model}".
+#' print method for class \code{causal_model}.
 #'
 #' @param x An object of \code{causal_model} class, usually a result of
-#'   a call to \code{make_model} or \code{update_model}.
+#'   a call to \code{\link{make_model}} or \code{\link{update_model}}.
 #' @param ... Further arguments passed to or from other methods.
 #'
 #' @details
@@ -49,7 +49,7 @@ print.causal_model <- function(x, ...) {
 #' summary method for class "\code{causal_model}".
 #'
 #' @param object An object of \code{causal_model} class produced using
-#'   \code{make_model} or \code{update_model}.
+#'   \code{\link{make_model}} or \code{\link{update_model}}.
 #' @param include A character string specifying the additional objects to include in summary. Defaults to \code{NULL}. See details for full list of available values.
 #' @param ... Further arguments passed to or from other methods.
 #'
@@ -58,9 +58,9 @@ print.causal_model <- function(x, ...) {
 #'   \item \code{"parents"} a list of parents of all nodes in a model,
 #'   \item \code{"parameters"} a vector of 'true' parameters,
 #'   \item \code{"parameter_names"} a vector of names of parameters,
-#'   \item \code{"data_types"} a list with the all data  types consistent with the model; for options see \code{"?get_all_data_types"},
-#'   \item \code{"prior_event_probabilities"} a vector of prior data (event) probabilities given a parameter vector; for options see \code{"?get_event_probabilities"},
-#'   \item \code{"prior_hyperparameters"} a vector of alpha values used to parameterize Dirichlet prior distributions; optionally provide node names to reduce output \code{"inspect(prior_hyperparameters, c('M', 'Y'))"}
+#'   \item \code{"data_types"} a list with the all data  types consistent with the model; for options see \code{?get_all_data_types},
+#'   \item \code{"prior_event_probabilities"} a vector of prior data (event) probabilities given a parameter vector; for options see \code{?get_event_probabilities},
+#'   \item \code{"prior_hyperparameters"} a vector of alpha values used to parameterize Dirichlet prior distributions; optionally provide node names to reduce output \code{inspect(prior_hyperparameters, c('M', 'Y'))}
 #' }
 #'
 #' @details
@@ -223,10 +223,10 @@ summary.causal_model <- function(object, include = NULL, ...) {
 #'   \item \code{"parameter_matrix"} A matrix mapping from parameters into causal types,
 #'   \item \code{"causal_types"} A data frame listing causal types and the nodal types that produce them,
 #'   \item \code{"nodal_types"} A list with the nodal types of the model,
-#'   \item \code{"data_types"} A list with the all data types consistent with the model; for options see `"?get_all_data_types"`,
-#'   \item \code{"prior_hyperparameters"} A vector of alpha values used to parameterize Dirichlet prior distributions; optionally provide node names to reduce output `inspect(prior_hyperparameters, c('M', 'Y'))`
+#'   \item \code{"data_types"} A list with the all data types consistent with the model; for options see \code{?get_all_data_types},
+#'   \item \code{"prior_hyperparameters"} A vector of alpha values used to parameterize Dirichlet prior distributions; optionally provide node names to reduce output \code{inspect(prior_hyperparameters, c('M', 'Y'))}
 #'   \item \code{"prior_distribution"} A data frame of the parameter prior distribution,
-#'   \item \code{"prior_event_probabilities"} A vector of data (event) probabilities given a single (sepcified) parameter vector; for options see `"?get_event_probabilities"`,
+#'   \item \code{"prior_event_probabilities"} A vector of data (event) probabilities given a single (specified) parameter vector; for options see \code{?get_event_probabilities},
 #'   \item \code{"ambiguities_matrix"} A matrix mapping from causal types into data types,
 #'   \item \code{"type_prior"} A matrix of type probabilities using priors,
 #'   \item \code{"type_posterior"} A matrix of type probabilities using posteriors,
@@ -299,19 +299,25 @@ print.summary.causal_model <-
         nt <- nodal_types[[n]]
         interpret <- attr(nodal_types, "interpret")[[n]]
         stop_at <- min(length(nt), 16)
-        cat(paste0("$", n, "\n"))
+        cat(paste0("\nNodal types for ", n, ":\n"))
 
         cat(paste0(nt[1:stop_at], collapse = "  "))
 
         if (stop_at != length(nt)) {
           cat(paste0(" ...", length(nt) - 16, " nodal types omitted"))
         }
-        cat("\n\n")
-        print(interpret)
-        cat("\n")
+          cat("\n")
+          if(!is.null(interpret)) {
+          cat(paste0("\nGuide to interpreting nodal types for ", n, ":\n"))
+
+          cat("\n")
+          print(interpret)
+          cat("\n")
+          }
+
       }
 
-      cat("Number of types by node:\n")
+      cat("Number of nodal types by node:\n")
 
       print(vapply(nodal_types, length, numeric(1), USE.NAMES = TRUE))
 
