@@ -37,8 +37,18 @@ testthat::test_that(
     expect_error(make_model("X -> S <- Y; S <-> Z"))
     expect_error(make_model(c("X -> Y" ,  "M -> Y")))
     expect_error(make_model(1))
+    expect_error(make_model("X ->"))
+    expect_error(make_model("X -> -> Y"))
     expect_error(make_model("institutions -> political_inequality"))
     expect_error(make_model("political-inequality <- institutions"))
+    expect_error(make_model("institutions -> political>inequality"))
+    expect_error(make_model("institutions -> political<inequality"))
+    expect_error(make_model("X.exp( -> Y"))
+    expect_error(make_model("X.log( -> Y"))
+    expect_error(make_model("X^Y -> Y"))
+    expect_error(make_model("X/Y -> Y"))
+    expect_error(make_model("X[Y] -> Y"))
+    expect_error(make_model("X:|:Y -> Y"))
     expect_error(make_model("X -> Y; Y -> X"))
     expect_error(make_model("X -> M; M -> W; W -> X; Z -> Y"))
   }
