@@ -1,9 +1,3 @@
-
-
-
-
-
-
 context("Set_prior_distribution")
 
 testthat::skip_on_cran()
@@ -12,11 +6,10 @@ testthat::test_that(
 	desc = "Check messages.",
 
 	code = {
-		expect_message(make_model("X -> Y") |>
-		                 grab("prior_distribution", 3))
 		expect_equal(make_model("X -> Y") |>
-		               set_prior_distribution(n_draws = 10) |>
-		               grab("prior_distribution") |> nrow(), 10)
+		               set_prior_distribution(30) |>
+		                 inspect("prior_distribution") |>
+		               dim(), c(30, 6))
 	}
 )
 
@@ -30,7 +23,7 @@ testthat::test_that(
   code = {
     expect_equal(make_model("X") |>
                    set_prior_distribution(n_draws = 10) |>
-                   grab("prior_distribution") |>
+                   inspect("prior_distribution") |>
                    ncol(), 2)
   }
 )
@@ -41,7 +34,7 @@ testthat::test_that(
   desc = "Deprecated get_prior_distribution.",
 
   code = {
-    expect_warning(make_model("X") |>
+    expect_warning(make_model("X -> Y") |>
                    CausalQueries:::get_prior_distribution(n_draws = 10) |>
                    ncol())
   }
